@@ -2,14 +2,14 @@
 import logging
 from enum import Enum
 from pathlib import Path
-from typing import Dict, List
+from typing import Dict, List, Optional, Union
 
 import numpy as np
 import pandas as pd
 
 from sbmlsim.combine import mathml
 from sbmlsim.result import XResult
-from sbmlsim.units import DimensionalityError, Quantity, UnitRegistry
+from sbmlsim.units import DimensionalityError, Quantity, UnitRegistry, UnitsInformation
 from sbmlsim.utils import deprecated
 
 
@@ -41,13 +41,14 @@ class Data(object):
         function=None,
         variables=None,
     ):
+        """Construct data."""
         self.experiment = experiment
-        self.index = index
-        self.task_id = task
-        self.dset_id = dataset
+        self.index: str = index
+        self.task_id: str = task
+        self.dset_id: str = dataset
         self.function = function
         self.variables = variables
-        self.unit = None
+        self.unit: Optional[str] = None
 
         if (not self.task_id) and (not self.dset_id) and (not self.function):
             raise ValueError(
@@ -62,6 +63,7 @@ class Data(object):
 
     def __str__(self) -> str:
         """Get string."""
+        s: str
         if self.is_task():
             s = f"Data(index={self.index}, task_id={self.task_id})|Task"
         elif self.is_dataset():
@@ -73,6 +75,7 @@ class Data(object):
     @property
     def sid(self) -> str:
         """Get id."""
+        sid: str
         if self.task_id:
             sid = f"{self.task_id}__{self.index}"
         elif self.dset_id:
@@ -95,7 +98,7 @@ class Data(object):
         return self.function is not None
 
     @property
-    def dtype(self) -> str:
+    def dtype(self) -> "Data.Types":
         """Get data type."""
         if self.task_id:
             dtype = Data.Types.TASK
@@ -162,22 +165,22 @@ class Data(object):
                 logger.error(error_msg)
                 raise KeyError(error_msg)
             try:
-                self.unit = dset.udict[uindex]
+                self.unit = dset.uinfo[uindex]
             except KeyError as err:
                 logger.error(
                     f"Units missing for key '{uindex}' in dataset: "
                     f"'{self.dset_id}'. Add missing units to dataset."
                 )
                 raise err
-            x = dset[self.index].values * dset.ureg(dset.udict[uindex])
+            x = dset[self.index].values * dset.uinfo.ureg(dset.uinfo[uindex])
 
         elif self.dtype == Data.Types.TASK:
             # read results of task
-            xres = self.experiment.results[self.task_id]  # type: XResult
+            xres: XResult = self.experiment.results[self.task_id]
             if not isinstance(xres, XResult):
                 raise ValueError("Only Result objects supported in task data.")
 
-            self.unit = xres.udict[self.index]
+            self.unit = xres.uinfo[self.index]
             # FIXME: complete data must be kept
             # print(xres)
             x = xres.dim_mean(self.index)
@@ -240,7 +243,7 @@ class DataSeries(pd.Series):
     """DataSet - a pd.Series with additional unit information."""
 
     # additional properties
-    _metadata = ["udict", "ureg"]
+    _metadata = ["uinfo"]
 
     @property
     def _constructor(self):
@@ -255,13 +258,11 @@ class DataSet(pd.DataFrame):
     """DataSet.
 
      pd.DataFrame with additional unit information in the form
-    of a unit dictionary 'udict' (Dict[str, str]) mapping column
-    keys to units. The UnitRegistry is the UnitRegistry conversions
-    are calculated on.
+    of UnitInformations.
     """
 
     # additional properties
-    _metadata = ["udict", "ureg"]
+    _metadata = ["uinfo", "Q_"]
 
     @property
     def _constructor(self):
@@ -276,10 +277,9 @@ class DataSet(pd.DataFrame):
 
         Requires using the numpy data instead of the series.
         """
-        return self.ureg.Quantity(
-            # downcasting !
+        return self.uinfo.ureg.Quantity(
             self[key].values,
-            self.udict[key],
+            self.uinfo[key],
         )
 
     def __repr__(self) -> str:
@@ -303,9 +303,9 @@ class DataSet(pd.DataFrame):
            'mean', 'value', 'sd' and 'se' columns
 
         :param df: pandas.DataFrame
-        :param udict: optional unit dictionary
-        :param ureg:
-        :return:
+        :param uinfo: optional units information
+
+        :return: dataset
         """
         if not isinstance(ureg, UnitRegistry):
             raise ValueError(
@@ -318,7 +318,7 @@ class DataSet(pd.DataFrame):
             udict = {}
 
         # all units from udict and DataFrame
-        all_udict = {}
+        all_udict: Dict[str, str] = {}
 
         for key in df.columns:
             # handle '*_unit columns'
@@ -381,13 +381,15 @@ class DataSet(pd.DataFrame):
                     setattr(df, f"{key}_unit", unit)
 
         dset = DataSet(df)
-        dset.udict = all_udict
-        dset.ureg = ureg
+        dset.uinfo = UnitsInformation(all_udict, ureg=ureg)
+        dset.Q_ = dset.uinfo.ureg.Quantity
         return dset
 
-    def unit_conversion(self, key, factor: Quantity, filter=None):
+    def unit_conversion(self, key, factor: Quantity) -> None:
         """Convert the units of the given key in the dataset.
 
+        Changes values in place in the DataSet.
+
         The quantity in the dataset is multiplied with the conversion factor.
         In addition to the key, also the respective error measures are
         converted with the same factor, i.e.
@@ -407,14 +409,14 @@ class DataSet(pd.DataFrame):
         :return: None
         """
         if key in self.columns:
-            if key not in self.udict:
+            if key not in self.uinfo:
                 raise ValueError(
                     f"Unit conversion only possible on keys which have units! "
                     f"No unit defined for key '{key}'"
                 )
 
             # unit conversion and simplification
-            new_quantity = self.ureg.Quantity(self[key], self.udict[key]) * factor
+            new_quantity = self.uinfo.Q_(self[key], self.uinfo[key]) * factor
             new_quantity = new_quantity.to_base_units().to_reduced_units()
 
             # updated values
@@ -425,7 +427,7 @@ class DataSet(pd.DataFrame):
                 if err_key in self.columns:
                     # error keys not stored in udict, only the base quantity
                     new_err_quantity = (
-                        self.ureg.Quantity(self[err_key], self.udict[key]) * factor
+                        self.uinfo.Q_(self[err_key], self.uinfo[key]) * factor
                     )
                     new_err_quantity = (
                         new_err_quantity.to_base_units().to_reduced_units()
@@ -437,7 +439,7 @@ class DataSet(pd.DataFrame):
             new_units_str = (
                 str(new_units).replace("**", "^").replace(" ", "")
             )  # '{:~}'.format(new_units)
-            self.udict[key] = new_units_str
+            self.uinfo[key] = new_units_str
 
             if f"{key}_unit" in self.columns:
                 self[f"{key}_unit"] = new_units_str
@@ -449,7 +451,7 @@ class DataSet(pd.DataFrame):
 
 # @deprecated
 def load_pkdb_dataframe(
-    sid, data_path: [Path, List[Path]], sep="\t", comment="#", **kwargs
+    sid, data_path: Union[Path, List[Path]], sep="\t", comment="#", **kwargs
 ) -> pd.DataFrame:
     """Load TSV data from PKDB figure or table id.
 
