@@ -1,8 +1,9 @@
+"""Package for simulation experiments."""
+
 from .experiment import (
     SimulationExperiment,
     ExperimentDict,
     ExperimentResult,
-    JSONExperiment,
 )
 from .runner import ExperimentRunner
 from sbmlsim.report.experiment_report import ExperimentReport
