@@ -306,7 +306,10 @@ class Axis(BasePlotObject):
         if unit is None:
             unit = "?"
         if not name:
-            name = f"{label} [{unit}]"
+            if unit != "dimensionless":
+                name = f"{label} [{unit}]"
+            else:
+                name = f"{label} [-]"
 
         self.label = label
         self.name = name
@@ -795,8 +798,8 @@ class Figure(BasePlotObject):
 
     fig_dpi = 72
     fig_facecolor = "white"
-    fig_subplots_wspace = 0.15  # vertical spacing of subplots (fraction of axes)
-    fig_subplots_hspace = 0.15  # horizontal spacing of subplots (fraction of axes)
+    fig_subplots_wspace = 0.3  # vertical spacing of subplots (fraction of axes)
+    fig_subplots_hspace = 0.3  # horizontal spacing of subplots (fraction of axes)
     panel_width = 7
     panel_height = 5
     fig_titlesize = 25
