@@ -83,13 +83,13 @@ class MatplotlibFigureSerializer(object):
 
             ridx = subplot.row - 1
             cidx = subplot.col - 1
-            ax = fig.add_subplot(
+            ax: plt.Axes = fig.add_subplot(
                 gs[ridx : ridx + subplot.row_span, cidx : cidx + subplot.col_span]
-            )  # type: plt.Axes
+            )
 
             plot = subplot.plot
-            xax = plot.xaxis  # type: Axis
-            yax = plot.yaxis  # type: Axis
+            xax: Axis = plot.xaxis
+            yax: Axis = plot.yaxis
 
             # units
             if xax is None:
@@ -354,7 +354,7 @@ def add_line(
     kwargs["color"] = color
 
     if all_lines:
-        Q_ = xres.ureg.Quantity
+        Q_ = xres.uinfo.Q_
         # iterate over all dimensions besides time
         # all combinations
         dims = xres._redop_dims()
@@ -362,8 +362,8 @@ def add_line(
         indices = list(itertools.product(*index_vecs))
         for k, item in enumerate(indices):
             d = dict(zip(dims, item))
-            xi = Q_(xres[xid].isel(d).values, xres.udict[xid])
-            yi = Q_(xres[yid].isel(d).values, xres.udict[yid])
+            xi = Q_(xres[xid].isel(d).values, xres.uinfo[xid])
+            yi = Q_(xres[yid].isel(d).values, xres.uinfo[yid])
             # FIXME: these conversions should not be necessary
             if xunit:
                 xi = xi.to(xunit)
@@ -478,15 +478,15 @@ def add_data(
         kwargs["linestyle"] = "--"
 
     # data with units
-    x = dset[xid].values * dset.ureg(dset.udict[xid]) * xf
-    y = dset[yid].values * dset.ureg(dset.udict[yid]) * yf
+    x = dset[xid].values * dset.uinfo.ureg(dset.uinfo[xid]) * xf
+    y = dset[yid].values * dset.uinfo.ureg(dset.uinfo[yid]) * yf
     y_err = None
     y_err_type = None
     if yid_sd:
-        y_err = dset[yid_sd].values * dset.ureg(dset.udict[yid]) * yf
+        y_err = dset[yid_sd].values * dset.uinfo.ureg(dset.uinfo[yid]) * yf
         y_err_type = "SD"
     elif yid_se:
-        y_err = dset[yid_se].values * dset.ureg(dset.udict[yid]) * yf
+        y_err = dset[yid_se].values * dset.uinfo.ureg(dset.uinfo[yid]) * yf
         y_err_type = "SE"
 
     # convert
