@@ -1,14 +1,12 @@
-"""
-Helpers related to logging
-"""
-import coloredlogs
+"""Helpers related to logging."""
+import coloredlogs  # type: ignore
 
 
 coloredlogs.install(level="INFO", fmt="%(levelname)s %(message)s")
 
 
 class bcolors:
-    """ Colors for styling log. """
+    """Colors for styling log."""
 
     HEADER = "\033[95m"
     OKBLUE = "\033[94m"
